@@ -43,7 +43,7 @@ function(x,latent=FALSE,index=TRUE,...) {
     } else {
       allvars <- manifest(x)
     }
-    M <- as(Graph(x), Class="matrix")
+    M <- x$M
     res <- c()
     for (i in allvars)
       if (!any(M[,i]==1) & any(M[i,]==1)) 
