@@ -91,13 +91,17 @@ weibull.lvm <- function(scale=1.25,shape=2,cens=Inf,breakties=0) {
       T <- T+runif(n,0,breakties)
     if (is.function(cens))
       cens <- cens(n,...)
-    Delta <- (T<cens)
-    if (any(!Delta)) {
-      T[!Delta] <- cens[!Delta]
+    if (is.finite(cens[1])) {
+      Delta <- (T<cens)
+      if (any(!Delta)) {
+        T[!Delta] <- cens[!Delta]
       S <- Surv(T,Delta*1)      
-    }
-    else
+      } else {
+        S <- T
+      }
+    } else {
       S <- T
+    }
     return(S)
   }
   return(f)
@@ -124,7 +128,7 @@ probit.lvm <- binomial.lvm("probit")
 ##' @aliases sim sim.lvmfit sim.lvm functional functional<-
 ##' functional.lvm functional<-.lvm distribution distribution distribution<-
 ##' distribution.lvm distribution<-.lvm heavytail heavytail<- weibull.lvm
-##' binomial.lvm poisson.lvm uniform.lvm normal.lvm probit.lvm logit.lvm student.lvm
+##' binomial.lvm poisson.lvm uniform.lvm normal.lvm probit.lvm logit.lvm student.lvm coxGompertz.lvm coxWeibull.lvm coxExponential.lvm 
 ##' @usage
 ##' \method{sim}{lvm}(x, n = 100, p = NULL, normal = FALSE, cond = FALSE,
 ##' sigma = 1, rho = 0.5, X, unlink=FALSE, ...)
